NAME

Dicop::Data::User - an administrator account

SYNOPSIS

use Dicop::Data::User;

$user = Dicop::Data::User->new( { name => 'me', pwdhash => '0123..45' });

REQUIRES

perl5.005, Exporter, Dicop::Item

EXPORTS

Exports nothing on default.

DESCRIPTION

For a description of fields a user has, see doc/Objects.pod.

BUGS

None known yet.

AUTHOR

(c) Bundesamt fuer Sicherheit in der Informationstechnik 1998-2006

DiCoP is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License version 2 as published by the Free Software Foundation.

See http://www.bsi.de/ for more information.