NAME
Dicop::Data::Jobtype - a job type in the dicop system
SYNOPSIS
use Dicop::Data::Jobtype;
REQUIRES
perl5.005, Exporter, Dicop::Item, Dicop
EXPORTS
Exports nothing on default.
DESCRIPTION
For a description of fields a jobtype has, see doc/Objects.pod.
METHODS
extra_fieldnames
@fields = $jobtype->extra_fieldnames();
Returns the names of the extra fields nec. for jobs of this type as an array.
extra_files
@files = $jobtype->extra_files($architecture);
Return list of extra filenames necc. for this jobtype, the files are relative to the worker dir, e.g. read linux/this.file.
get_as_string
Return a field of the object as an ASCII string suitable for HTML output:
$object->get_as_string('foo');
get_as_hex
Return a field of the object as an hexified string, or as a fallback, as normal string via get_as_string. The hexify happens only for certain special fields, all other are returned as simple strings:
$object->get_as_hex('foo');
get
Return the value of a specified field of the object:
$object->get('foo');
change
Change a field's value after checking that the field can be changed (via can_change) and checking the new value. If the new value does not conform to the expected format, it will be silently modifed (f.i. invalid characters might be removed) and then the change will happen:
$object->change('foo','bar'); # will change $object->{foo} to bar
# if foo can be changed
can_change
Return true if the field's value can be changed.
die ("Can not change field $field\n") if !$object->can_change($field);
BUGS
None known yet.
AUTHOR
(c) Bundesamt fuer Sicherheit in der Informationstechnik 1998-2006
DiCoP is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License version 2 as published by the Free Software Foundation.
See http://www.bsi.de/ for more information.